@@ -276,9 +276,6 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
         else:
             size = calculated_mem_util
             auto = 1
-        if(size>16.0):
-            printError("Error. We currently do not support models larger than 16 GB in our alpha test. Please try again with a smaller model")
-            return(False)
     except Exception as e:
         logging.error(e, exc_info=True)
         printError(f"ERROR. We were unable to determine the memory needs of your model, getting an error {e} \nPlease try and run your container locally to make sure it works, or provide a memory limit and redeploy.")
