@@ -34,8 +34,8 @@ def get_pod_logs(model_name, pod_name):
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("--model_name", help="The name of your deployed model", required=True)
-    parser.add_argument("--pod_name", help="The name of your pod", required=True)
+    parser.add_argument("--model-name", help="The name of your deployed model", required=True)
+    parser.add_argument("--pod-name", help="The name of your pod", required=True)
 
     args = parser.parse_args()
 
